@@ -66,9 +66,6 @@ subset.powdRlib <- function(x, refs, mode, ...) {
     x[[1]] <- x[[1]][keep_index]
     x[[3]] <- x[[3]][keep_index, ]
 
-    #Ensure they're ordered
-    x[[1]] <- x[[1]][order(names(x[[1]]))]
-    x[[3]] <- x[[3]][order(x[[3]][[1]]),]
 
   } else {
 
@@ -77,9 +74,6 @@ subset.powdRlib <- function(x, refs, mode, ...) {
     x[[1]] <- x[[1]][-remove_index]
     x[[3]] <- x[[3]][-remove_index, ]
 
-    #Ensure they're ordered
-    x[[1]] <- x[[1]][order(names(x[[1]]))]
-    x[[3]] <- x[[3]][order(x[[3]][[1]]),]
 
   }
 
