@@ -161,7 +161,7 @@ shiny::tabPanel("Reference Library Editor",
 shiny::tabPanel("Full Pattern Summation",
                 shiny::fluidRow(
                   shiny::column(3, shiny::wellPanel(
-                    shiny::h3("1. Load a sample for quantification"),
+                    shiny::h3("1. Load samples for quantification"),
                     shiny::helpText("Must be .xy format (space separated)"),
                     shiny::div(style="display: inline-block;vertical-align:top; width: 225px;",
                                shiny::fileInput(inputId = "loadXY",
@@ -170,16 +170,12 @@ shiny::tabPanel("Full Pattern Summation",
                                                 accept = c(".xy", ".XY"))),
                     shiny::div(style="display: inline-block;vertical-align:center; width: 0px;",
                                shinyWidgets::dropdownButton(
-                                 shiny::downloadLink(outputId = "download_soil_sand",
-                                                     label = "Sandstone_example.xy  "),
-                                 shiny::downloadLink(outputId = "download_soil_lime",
-                                                     label = "Limestone_example.xy  "),
-                                 shiny::downloadLink(outputId = "download_soil_granite",
-                                                     label = "Granite_example.xy  "),
-                                 shiny::downloadLink(outputId = "download_rj_mix1",
-                                                     label = "rockjock_mix1.xy  "),
-                                 shiny::downloadLink(outputId = "download_rj_mix2",
-                                                     label = "rockjock_mix2.xy  "),
+                                 shiny::downloadLink(outputId = "download_sandstone",
+                                                     label = "sandstone_soil.xy  "),
+                                 shiny::downloadLink(outputId = "download_limestone",
+                                                     label = "limestone_soil.xy  "),
+                                 shiny::downloadLink(outputId = "download_granite",
+                                                     label = "granite_soil.xy  "),
                                  circle = FALSE, status = "danger", icon = shiny::icon("question"),
                                  width = "300px", size = "sm")),
                     shiny::h3("2. Load a reference library"),
@@ -191,10 +187,10 @@ shiny::tabPanel("Full Pattern Summation",
                                                 accept = ".Rdata")),
                     shiny::div(style="display: inline-block;vertical-align:center; width: 0px;",
                                shinyWidgets::dropdownButton(
-                                 shiny::downloadLink(outputId = "download_example_ref",
-                                                     label = "example_powdRlib.Rdata"),
-                                 shiny::downloadLink(outputId = "download_rj_lib",
+                                 shiny::downloadLink(outputId = "download_rockjock",
                                                      label = "rockjock_powdRlib.Rdata"),
+                                 shiny::downloadLink(outputId = "download_mineral_library",
+                                                     label = "example_powdRlib.Rdata"),
                                  circle = FALSE, status = "danger", icon = shiny::icon("question"),
                                  width = "300px", size = "sm")),
                     shiny::h3("3. Select mode"),
@@ -206,7 +202,7 @@ shiny::tabPanel("Full Pattern Summation",
                     shiny::helpText("Select the optimisation routine"),
                     shiny::selectInput(inputId = "selectSolver_fps",
                                        label = NULL,
-                                       choices = c("BFGS", "Nelder-Mead", "CG", "L-BFGS-B", "NNLS"),
+                                       choices = c("BFGS", "Nelder-Mead", "CG", "NNLS"),
                                        selected = "BFGS"),
                     shiny::helpText("Select the objective function to minimise"),
                     shiny::selectInput(inputId = "selectOBJ_fps",
@@ -274,18 +270,21 @@ shiny::tabPanel("Full Pattern Summation",
                     shiny::tags$hr(),
                     DT::dataTableOutput("contents_fps"),
                     shiny::tags$hr(),
-                    plotly::plotlyOutput("line_fps", width = "auto", height = 1000),
+                    plotly::plotlyOutput("line_fps", width = "auto", height = 550),
                     shiny::tags$hr(),
                     shiny::h3("7. Download computed fit"),
-                    shiny::downloadButton(outputId = "download_fit",
-                                          label = "Download fitted patterns (.csv)"),
-                    shiny::downloadButton(outputId = "download_mins",
-                                          label = "Download phase concentrations (.csv)"),
+                    shiny::downloadButton(outputId = "download_meas",
+                                          label = "Download measured pattern (.xy)"),
+                    shiny::downloadButton(outputId = "download_calc",
+                                          label = "Download fitted pattern (.xy)"),
+                    shiny::downloadButton(outputId = "download_concs",
+                                          label = "Download concentrations (.csv)"),
                     shiny::downloadButton(outputId = "download_fps",
                                           label = "Download powdRfps object (.Rdata)")
                   ))
-                  ) # end fluidRow
-                ),
+                ) # end fluidRow
+),
+
 
 #################################
 ## TAB 5: RESULTS VIEWER EDITOR
@@ -305,7 +304,7 @@ shiny::tabPanel("Results Viewer/Editor",
                     shiny::helpText("Must be a .Rdata powdRlib object of the library used to
                                     produce the original results"),
                     shiny::div(style="display: inline-block;vertical-align:top; width: 225px;",
-                               shiny::fileInput(inputId = "loadLib_editor",
+                               shiny::fileInput(inputId = "loadLIB_fps_editor",
                                                 label = NULL,
                                                 multiple = FALSE,
                                                 accept = ".Rdata")),
@@ -313,7 +312,7 @@ shiny::tabPanel("Results Viewer/Editor",
                     shiny::helpText("Choose the optimisation routine"),
                     shiny::selectInput(inputId = "selectSolver_editor",
                                        label = NULL,
-                                       choices = c("BFGS", "Nelder-Mead", "CG", "L-BFGS-B", "NNLS"),
+                                       choices = c("BFGS", "Nelder-Mead", "CG", "NNLS"),
                                        selected = "BFGS"),
                     shiny::helpText("Choose the objective function to minimise"),
                     shiny::selectInput(inputId = "selectOBJ_editor",
@@ -351,7 +350,7 @@ shiny::tabPanel("Results Viewer/Editor",
                     shiny::uiOutput("align_editor_ui"),
                     shiny::helpText("Adjust the shifting parameter"),
                     shiny::sliderInput("shift_editor", label = NULL, min = 0,
-                                       max = 0.1,
+                                       max = 0.5,
                                        value = c(0)),
                                        shiny::helpText(shiny::withMathJax("Adjust the 2\\(\\theta\\) range for
                                                                           full pattern summation")),
@@ -378,11 +377,13 @@ shiny::tabPanel("Results Viewer/Editor",
                                shiny::helpText("Note: Computation may take several minutes.")),
                     shiny::tags$hr(),
                     DT::dataTableOutput("contents_editor"),
-                    plotly::plotlyOutput("line_editor", width = "auto", height = 1000),
+                    plotly::plotlyOutput("line_editor", width = "auto", height = 550),
                     shiny::tags$hr(),
-                    shiny::h3("7. Download computed fit"),
-                    shiny::downloadButton(outputId = "download_fit_editor",
-                                          label = "Download edited fitted patterns (.csv)"),
+                    shiny::h3("8. Download computed fit"),
+                    shiny::downloadButton(outputId = "download_meas_editor",
+                                          label = "Download edited measured pattern (.xy)"),
+                    shiny::downloadButton(outputId = "download_calc_editor",
+                                          label = "Download edited fitted pattern (.xy)"),
                     shiny::downloadButton(outputId = "download_mins_editor",
                                           label = "Download edited phase concentrations (.csv)"),
                     shiny::downloadButton(outputId = "download_editor",
@@ -399,17 +400,7 @@ shiny::tabPanel("Results Viewer/Editor",
 shiny::tabPanel("Help",
                 shiny::fluidRow(
                   shiny::column(12, align = "center",
-                                shiny::h1("Video tutorials"),
-                                shiny::helpText("Select an option to view a video tutorial for each tab of this
-                                                Shiny application"),
-                                shiny::selectInput(inputId = "selectVIDEO",
-                                                   label = NULL,
-                                                   multiple = FALSE,
-                                                   choices = list("Reference Library Builder" = "RGEhe_hdDkM",
-                                                                  "Reference Library Viewer" = "9hVdSXk2uyw",
-                                                                  "Reference Library Editor" = "mNQC1TLXJWM",
-                                                                  "Full Pattern Summation" = "w3qO2U3UqT0",
-                                                                  "Results Editor" = "R7i8vJgVCvQ")),
+                                shiny::h1("Video tutorial"),
                                 shiny::uiOutput("video")
                                 )
                   ) # end fluidRow
